package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`/@`!````\"5``#0````@LP```````#0`(``,
M`"@`&P`:``8````T````-`!``#0`0`"``0``@`$```0````$`````P```+0!
M``"T`4``M`%``!H````:````!`````$````!````````````0````$``5!(`
M`%02```$`````!````$`````(````"!````@0`"M,0``K3$```4`````$```
M`0````!@````8$```&!``"Q&```L1@``!``````0```!````@*X``("^0`"`
MOD``@`,``+03```&`````!````(```"(K@``B+Y``(B^0``8`0``&`$```8`
M```$````!````-`!``#0`4``T`%``$0```!$````!`````0```!0Y71D2)\`
M`$B?0`!(GT``[````.P````$````!````%'E=&0`````````````````````
M``````8````0````4N5T9("N``"`OD``@+Y``(`!``"``0``!`````$```"`
M%01E````````````````````````````*```!````"]L:6)X,S(O;&0M;&EN
M=7@M>#,R+G-O+C(````$````$`````$```!'3E4```````,````$````````
M``0````4`````P```$=.50#\S)2]!<]W+:CU=KGV3C`0UU&JN!$```!*````
M"`````@`````$!`$)4`$@"@```"@A@"`@`$```LH!`@XH!)%B@``"`````!*
M````30```%````!1````5P```%@```!9````6P```%P`````````7@```%\`
M``!@````80``````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8
M'.)'Q@&R`8MOK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>
M,F+;[=O-XYX-.I<+?ZF<F^&G`@JCX/M)`````````````````````#L"````
M`````````!(```#5`@`````````````2````#@$`````````````$@```!(#
M`````````````!(```":`@`````````````2````E0``````````````$@``
M``,!`````````````!$```"5`0`````````````2````0`(`````````````
M$@```!,!`````````````!(```!(`@`````````````2````)`$`````````
M````$@```#(#`````````````!(````3```````````````@`````P(`````
M````````$@```"H#`````````````!(```#N`@`````````````2````'0(`
M````````````$@```%,#`````````````"$```!5`0`````````````2````
MM@``````````````$@```$4!`````````````!(```#R`0`````````````2
M````;P(`````````````$@```#<!`````````````!(```!1`@``````````
M```2````(@``````````````(````+,!`````````````!(```#=`@``````
M```````2````/@``````````````(````(P"`````````````!(```!8````
M```````````2````A0$`````````````$@```%0#`````````````!$```!U
M```````````````2`````@0`````````````$@```/(``````````````!(`
M``"&```````````````2````M0(`````````````$@```'X"````````````
M`!(````Y`P`````````````2````O`(`````````````$@```/X"````````
M`````!(```#6```````````````2````"P,`````````````$@```&D"````
M`````````!(```!W`0`````````````2````A0(`````````````$@```'<"
M`````````````!(```#G`@`````````````1````:0$`````````````$@``
M``D"`````````````!(```"3`@`````````````2````4@,`````````````
M$0```!@!`````````````!(```"A`@`````````````2````'`,`````````
M````$@```"0"`````````````!(```!<`P`````````````2````R@(`````
M````````$@```*<"`````````````!(```"A```````````````2````0`,`
M````````````$@```&("`````````````!(```"@`0`````````````2````
MY0``````````````$0```+X!`````````````!$```"L`0`````````````2
M````*0(`````````````$@```%X!`````````````!(```!F````````````
M```2````]0(`````````````$@```,0``````````````!(````+!```L%!`
M`%T````2``T`7`0``'!"0`"*"@``$@`-`$T#``#@(T``"`(``!(`#0!\`P``
M$#Q```4````2``T`J@,```!-0`"A`P``$@`-`(($```@/$``]`$``!(`#0!+
M!````,)````````0`!@`C0,``"`^0``D````$@`-`,`#``#P0$``:@```!(`
M#0`7!````&!```0````1``\`,P0``/`Z0``N````$@`-`%<$```TTD``````
M`!``&`!P!```D$%``-,````2``T`)@0``/#!0```````$``7`.0#``!0/D``
MT````!(`#0!I!````,)````````0`!<`CP0``/S!0``$````$0`7`)H#``"`
M44``!0```!(`#0`L!```\"5``#`````2``T`.P0``!!10`!E````$@`-`"@$
M``#PP4```````"``%P#P`P``8$%``"8````2``T`S@,``&`[0`"K````$@`-
M`)D$```@/T``R0$``!(`#0``;&EB<&5R;"YS;RXU+C(X+C``7U]G;6]N7W-T
M87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!0
M97)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E
M<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?
M9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?
M9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A
M=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E
M<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS
M;RXV`&QI8G!T:')E860N<V\N,`!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`'!T
M:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!L:6)C+G-O
M+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL
M:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K
M`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S
M=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI8F-R
M>7!T+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C
M7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?
M7V1A=&%?<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`7U]B<W-?<W1A
M<G0`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H
M`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N
M,38`+W5S<B]L:6)X,S(O<&5R;#4O-2XR."XP+W@X-E\V-"UP;&0M;&EN=7@M
M9VYU>#,R+71H<F5A9"UM=6QT:2]#3U)%`````@`"`````@`"``````````(`
M`@`"`````@````,``@`"``,``@`````````#``(````"```````"`````@``
M`````@````(```````(``@`"``(``@````(``@````(``@`"`````P`"``(`
M```"``(``P`"``(``@````(``@`````````"``,```````(````!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
MX@$``!`````@````EI&6!@```P"F!`````````$``0`Q`@``$`````````"6
MD98&```"`*8$````````H+]```8'````````J+]```8,````````L+]```8.
M````````N+]```8;````````P+]```8>````````R+]```8A````````T+]`
M``8B````````V+]```8C````````X+]```8R````````Z+]```8_````````
M\+]```9"````````^+]```9#````````&,!```<!````````(,!```<"````
M````*,!```<#````````,,!```<$````````.,!```<%````````0,!```<&
M````````2,!```<(````````4,!```<)````````6,!```<*````````8,!`
M``<+````````:,!```<-````````<,!```</````````>,!```<0````````
M@,!```<1````````B,!```<2````````D,!```<4````````F,!```<5````
M````H,!```<6````````J,!```<7````````L,!```<8````````N,!```<9
M````````P,!```<:````````R,!```<<````````T,!```<=````````V,!`
M``<?````````X,!```<@````````Z,!```<D````````\,!```<E````````
M^,!```<F`````````,%```<G````````",%```<H````````$,%```<I````
M````&,%```<J````````(,%```<K````````*,%```<L````````,,%```<M
M````````.,%```<N````````0,%```<O````````2,%```<P````````4,%`
M``<Q````````6,%```<S````````8,%```<T````````:,%```<U````````
M<,%```<W````````>,%```<X````````@,%```<Y````````B,%```<Z````
M````D,%```<[````````F,%```<\````````H,%```<]````````J,%```<^
M````````L,%```=`````````N,%```=!````````P,%```=$````````R,%`
M``=%````````T,%```=&````````V,%```='````````X,%```=(````````
MZ,%```=)````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S__U53@^PHB7PD#(U\)`R)="0(C70D"(E4)`2-5"0$9(L$)1@```")1"0<
M,<#HH/___XLUDIL``(L]O)L``$B)\NAL+0``BP7&FP``9X`X``^$'0$``(L=
M9IL``&>+.^A^_O__9XL[9X"(!@,```+H;O[__V>`B`8#```!BT0D#(UX!8'_
M____/P^'60$``,'G`NC[_O__1(M,)`B-#4D]``#'!9ZM```$````08G`B061
MK0``O@$```!G08L19XE(!(T-)CT``&>)2`QGB1#'POS!0`!GBQ)GB5`(BU0D
M#(/Z`7X7#Q]$``!G08L\L6=!B7RP#(/&`3GR=>Z+/5"M``!(B<&--3<6``!G
M0<=$D`P`````@\(#13'`Z)+[__^)Q87`='^+/2:M``"-7"08Z)W]__\QP$B)
MWHT]ACL``.A=#P``A<!T;HL]`ZT``.@>^___Z(G\__^)Z(M,)!QD,PPE&```
M``^%F````(/$*%M=P^@Z_/__B074K```A<!T>4B)Q^B(_/__BQTRF@``9XL[
MZ$K]__]GQH"I!@```.FW_O__BSVGK```Z)+[__^)Q>EO____BSV1K```A?]T
M!^@,*P``ZX&-/:TZ``!(B=[HS`X``(G'B05PK```A<`/A&/____KV8LU+)H`
M`(T]A#H``#'`Z'?]__^_`0```.A-^O__Z)C[__\/'X0``````/,/'OHQ[4&)
MT8LT)(/$!(GB@^3P4%1!Q\"`44``Q\$044``Q\?@(T``_Q7)F0``]/,/'OK#
M9BX/'X0``````)"-/<J;``"-!<2;```Y^'00BP5RF0``A<!T!HG`_^!FD,-F
M9BX/'X0```````\?0`"-/9J;``"--92;```I_L'^`HGPP>@?`<;1_G04BP4^
MF0``A<!T"HG`_^!F#Q]$``##9F8N#Q^$```````/'T``@#U9FP```'4758GE
MZ'_____&!4B;```!7<-F#Q]$``##9F8N#Q^$```````/'T``ZXYF+@\?A```
M````#Q]``$%5C7<<05154X'L6`$``&2+!"48````B80D3`$``#'`B>)$C4)`
MB=`/'X0``````&>+#H/`!(/&!`_)9XE(_$$YP'7LC8H``0``9@\?1```9XM"
M-&<S0B"#P@1G,T($9S-"_-'`9XE"/#G*=>-GBR]GBU\0BP0D9T2+5PB)ZF=$
MBT\,9T2+7P1!B>S!P@5%B="+3"0$0<',`HV$`YEY@EI$BVPD#`'"1(G008V,
M"9EY@EI$,<A$(=A$,<@!T$2)VL'*`D$QT(G602'H1#'F13'0(<9!`<B)P3'6
MP<@"P<$%0HV4*IEY@EI$BVPD$$$!R(M,)`A!C8P*F7F"6@'.1(G!P<$%`<Y$
MB>$QP40AP4'!R`)$,>%'C:0LF7F"6D2+;"04`=&)\L'"!0'1B<)$,<(A\C'"
M0HV$*)EY@EI$BVPD&$0!XD&)S$'!Q`7!S@)$`>)%B<1!,?1!(<S!R0)%,<1'
MC80HF7F"6D2+;"0<1`'@08G40<'$!40!X$&)]$$QS$$AU,'*`D$Q]$*-M"Z9
M>8):1(ML)"!%`>!!B<1!P<0%10'@08G,03'402'$P<@"03',0HV,*9EY@EI$
MBVPD)$0!YD6)Q$'!Q`5$`>9!B=1!,<1%(<1!P<@"03'40HV4*IEY@EI$BVPD
M*$0!X4&)]$'!Q`5$`>%!B<1%,<1!(?3!S@)!,<1"C80HF7F"6D2+;"0L1`'B
M08G,0<'$!40!XD6)Q$$Q]$$AS,')`D4QQ$>-A"B9>8):1(ML)#!$`>!!B=1!
MP<0%1`'@08GT03',02'4P<H"03'T0HVT+IEY@EI$BVPD-$4!X$&)Q$'!Q`5%
M`>!!B<Q!,=1!(<3!R`)!,<Q"C8PIF7F"6D2+;"0X1`'F18G$0<'$!40!YD&)
MU$$QQ$4AQ$$QU$*-E"J9>8):1(ML)#Q$`>%!B?1!P<0%1`'A0<'(`D&)Q$4Q
MQ$$A],'.`D$QQ$*-A"B9>8):1(ML)$!$`>)!B<Q!P<0%1`'B18G$03'T02',
MP<D"13'$1XV$*)EY@EI$BVPD1$0!X$&)U$'!Q`5$`>!!B?1!,<Q!(=3!R@)!
M,?1"C;0NF7F"6D2+;"1(10'$08G`0<'`!44!Q$&)R$$QT$$AP,'(`D$QR$*-
MC"F9>8):1(ML)$Q!`?!$B>;!Q@5!`?")UC'&1"'F,=9!P<P"0HV4*IEY@EH!
MSD2)P<'!!0'.B<%$,>%$(<$QP0'*B?'!P04!RD2)P42+1"10P<D"0HV$`*'K
MV6Y%B>!!,<A!,?#!S@)!`<")T$&)]8G.P<`%1#'N00'`BT0D5#'608V$!*'K
MV6X!QD2)P,'`!0'&B="+5"18P<@"C901H>O9;D2)Z3'!1#'!0<'(`@'1B?+!
MP@4!T8M4)%Q%C:05H>O9;HG"1#'",?)$`>)!B<S!S@)!P<0%1`'B1(MD)&!&
MC:0@H>O9;D2)P#'P,<C!R0)$`>!!B=1!P<0%1`'@1(MD)&1'C:0@H>O9;D&)
M\$$QR$$QT,'*`D4!X$&)Q$'!Q`5%`>!$BV0D:$:-I":AZ]ENB<XQUC'&P<@"
M1`'F18G$0<'$!40!YD2+9"1L1HVD(:'KV6Z)T3'!1#'!0<'(`D0!X4&)]$'!
MQ`5$`>%$BV0D<$:-I"*AZ]ENB<)$,<(Q\D0!XD&)S$'!Q`5$`>)$BV0D=,'.
M`D:-I""AZ]EN1(G`,?`QR,')`D0!X$&)U$'!Q`5$`>!$BV0D>$>-I""AZ]EN
M08GP03'(03'0P<H"10'@08G$0<'$!44!X$2+9"1\1HVD)J'KV6Z)SC'6,<;!
MR`)$`>9%B<1!P<0%1`'F1(ND)(````!&C:0AH>O9;HG1,<%$,<%!P<@"1`'A
M08GT0<'$!40!X42+I"2$````1HVD(J'KV6Z)PD0QPC'RP<X"1`'B08G,0<'$
M!40!XD2+I"2(````1HVD(*'KV6Y$B<`Q\#'(P<D"1`'@08G40<'$!40!X$2+
MI"2,````1XV$(*'KV6Y!B?1!,<Q!,=3!R@)%`<1!B<!!P<`%10'$1(N$))``
M``!"C;0&H>O9;D&)R$$QT$$QP,'(`D$!\$2)YL'&!4$!\(NT))0```"-C#&A
MZ]ENB=8QQD0QYD'!S`(!SD2)P<'!!0'.BXPDF````(V4"J'KV6Z)P40QX40Q
MP4'!R`(!T8GR18G%P<(%`=&+E"2<````C800H>O9;D2)XD0QPC'R`<*)R,'.
M`L'`!4$A]0'"1(G`"?`AR,')`D0)Z$2+K"2@````1XVD+-R\&X]!B?5$`>!!
MB=1!(<U!P<0%1`'@08GT00G,02'4P<H"10GL1(NL)*0```!'C80HW+P;CT&)
MS44!X$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDJ````$*-M"[<
MO!N/08G51`'F18G$02'%0<'$!40!YD&)U$$)Q$4AQ$4)[$2+K"2L````0HV,
M*=R\&X]!B<5$`>%!B?1!P<@"0<'$!44AQ40!X4&)Q$4)Q$$A],'.`D4)[$2+
MK"2P````0HV4*MR\&X]%B<5$`>)!B<Q!(?5!P<0%1`'B18G$00GT02',P<D"
M10GL1(NL)+0```!"C80HW+P;CT&)]40!X$&)U$$AS4'!Q`5$`>!!B?1!"<Q!
M(=3!R@)%">Q$BZPDN````$>-A"C<O!N/08G-10'@08G$02'50<'$!44!X$&)
MS$$)U$$AQ$4)[$2+K"2\````0HVT+MR\&X]!B=5$`>9%B<3!R`)!P<0%02'%
M1`'F08G400G$12'$0<'(`D4)[$2+K"3`````0HV,*=R\&X]!B<5$`>%!B?1%
M(<5!P<0%1`'A08G$10G$02'TP<X"10GL1(NL),0```!"C90JW+P;CT6)Q40!
MXD&)S$$A]4'!Q`5$`>)%B<1!"?1!(<S!R0)%">Q$BZPDR````$*-A"C<O!N/
M08GU1`'@08G402'-0<'$!40!X$&)]$$)S$$AU$4)[$2+K"3,````1XV$*-R\
M&X]!B<U%`>!!B<3!R@)!P<0%02'510'@08G,00G402'$P<@"10GL1(NL)-``
M``!"C;0NW+P;CT&)U40!YD6)Q$$AQ4'!Q`5$`>9!B=1!"<1%(<1!P<@"10GL
M1(NL)-0```!"C8PIW+P;CT&)Q40!X4&)]$4AQ4'!Q`5$`>%!B<1%"<1!(?3!
MS@)%">Q$BZPDV````$*-E"K<O!N/18G%1`'B08G,02'U0<'$!40!XD6)Q$$)
M]$$AS$4)[$2+K"3<````0HV$*-R\&X]!B?5$`>!!B=3!R0)!P<0%02'-1`'@
M08GT00G,02'4P<H"10GL1(NL).````!'C80HW+P;CT&)S44!X$&)Q$$AU4'!
MQ`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDY````$*-M"[<O!N/08G51`'F18G$
M02'%0<'$!40!YD&)U$$)Q$4AQ$'!R`)%">Q$BZPDZ````$*-C"G<O!N/08G%
M00',B?%%(<7!P05!`<R)P40)P2'Q1`GI1(NL).P```!"C90JW+P;CP'*1(GA
MP<X"P<$%08GU`<J+C"3P````C80(UL%BRD2)P3'Q1#'A0<',`@'!B=!$,>;!
MP`4QU@'!BX0D]````$&-A`#6P6+*`<:)R,'`!0'&B="+E"3X````P<@"08V4
M%=;!8LI%B>5!,<5!,<W!R0)!`=6)\D&)R(G!P<(%1#'!00'5BY0D_````#'Q
MP<X"08V4%-;!8LI$BZ0D!`$```'11(GJP<(%1XVD(-;!8LH!T8N4)``!``"-
MA!#6P6+*1(G"08GP,?)$,>H!PHG(P<`%`<)$B>C!R`)!,<!!,<C!R0)%`>!!
MB=1!P<0%10'@1(ND)`@!``!&C:0FUL%BRHG&,<XQUL'*`D0!YD6)Q$'!Q`5$
M`>9$BZ0D#`$``$:-I"#6P6+*B<@QT$0QP$'!R`)$`>!!B?1!P<0%1`'@1(ND
M)!`!``!&C:0AUL%BRHG11#'!,?'!S@)$`>%!B<1!P<0%1`'A1(ND)!0!``!&
MC:0BUL%BRD2)PC'R,<+!R`)$`>)!B<Q!P<0%1`'B1(ND)!@!``!'C80@UL%B
MRD&)]$$QQ$$QS,')`D4!Q$&)T$'!P`5%`<1$BX0D'`$``$*-M`;6P6+*08G`
M03'(03'0P<H"00'P1(GFP<8%00'PB[0D(`$``(VT,-;!8LJ)R#'01#'@0<',
M`@'P1(G&P<8%`?"+M"0D`0``C8PQUL%BRHG61#'F1#'&0<'(`@'.B<'!P04!
MSHN,)"@!``"-E`K6P6+*1(GA1#'!,<'!R`(!T8GR08G%P<(%`=&+E"0L`0``
M08V4%-;!8LI%B<1!,<1!,?1!`=2)RL'.`L'"!4$Q]4$!U(N4)#`!``!!,<W!
MR0)!C900UL%BRD6)X$$!U42)XD'!R`+!P@5!`=6+E"0T`0``C900UL%BRHGP
M,<A$,>!!B<P!T$2)ZD4QQ,'"!44Q[`'0BY0D.`$``(V4%M;!8LI$B>Y!`=2)
MPL'.`L'"!4$!U(N4)#P!``!%`>.-E!76P6+*9T2)7P0!T42)PC'R1`'.,<+!
MR`)GB7<,`<I$B>%!`<+!P05G1(E7"`'*00'89XD79T2)1Q"+A"1,`0``9#,$
M)1@```!U#8'$6`$``%M=05Q!7</H!>W__P\?1```05=!5D%505154X/L"$B%
M_P^$J@```(L%-(L``&=$BR!%A>0/A)<```!G#[8'A,!T!#P]=5LQVV=%BS0D
M187V=#5)B?5(B?U%B>=F#Q]$``!$B?>)VDB)[NC#Z___A<!U"&=!@#P>/70_
M08/'!&=%BS=%A?9UVH/$"$2)\%M=05Q!74%>05_#9@\?A```````B?N#PP%G
M#[8#A,!T!#P]=?$I^^N2#Q\`12GG18UT'@%!P?\"9T6)?0#KNP\?1```13'V
MZ[%F9BX/'X0``````%5(B?U3@^P89(L$)1@```")1"0,,<"-7"0(9@\?1```
M,<!(B=Y(B>_H`____X7`="^+!4F*``"+5"0(9XL`C0209XM0!&>)$(72=-0/
M'T``@\`$9XM0!&>)$(72=?+KP(M$)`QD,P0E&````'4&@\086UW#Z+?K__\/
M'X``````05=!5D%505152(GU4TB)^X/L*&2+!"48````B40D'#'`9X`^/74#
M@\4!2(GOZ,[L__^-="082(G?B40D"$&)QC'`Z&G^__]!B<6%P`^$#@$``$B)
MQ^BF[/__1#GP#X/=````BT0D&$2+)9*)``!$C32%`````&</M@.$P`^$C@$`
M`#P]#X2&`0``B=@/'T``@\`!9P^V$(32=`6`^CUU\"G8BWPD"&=%`S0DC7PX
M`NC\[/__9T&)!H7`#X1D`0``9T&+!"2+5"08C4L!9XL4D&</M@-GB`(\/70C
MA,!U#>L=#Q^``````#P]=!*#P0&#P@%G#[9!_V>(`H3`=>IGQ@(],<`/'T``
M9P^V#"AGB$P"`8/``83)=>\QP(M<)!QD,QPE&`````^%`0$``(/$*%M=05Q!
M74%>05_##Q]$```QP&8/'T0``&</MA0H9T&(5`4`@\`!A-)U[NN]#Q]``$2+
M)9F(``!G18L\)&=!BP^%R0^$GP```#'`ZP</'T``1(GH1(UH`6=#BQ2OA=)U
M\(TTA0P```"+!;.:``"%P'5/QP6EF@```0```(GWZ/[K__^)1"0,A<!T:D:-
M-*T`````1(G^2(G'1(GRZ%#I__]$BTPD#&=!B00D9T/'1*D$`````$2);"08
MZ8C^__]FD$2)_^B8Z?__08G!9T&)!"2%P'0@1HTTK0````#KS&:0,<#IB_[_
M_[X(````13'MZ7/___^X_____^GM_O__Z'WI__]F9BX/'X0``````&:005=!
M5D%505154X'LN````&2+!"48````B80DK````#'`2(7_=`EG@#\`2(G[=2F+
MA"2L````9#,$)1@````/A3,!``"!Q+@```!;74%<05U!7D%?PP\?`.C3Y___
MB<6%P'3,C40D$$2-)8<G``")1"0(1(TU>R<``$2-/7<G``!(B>_HR.?__X7`
M#X3(````1(UH$[D"````1(GG1(GN9_.F#Y?`'`"$P'35N0,```!$B>Y$B?=G
M\Z8/E\`<`(3`=+Y(B=_H]NG__T6)Z4R)STR)#"2)1"0,Z./I__^+5"0,C7P"
M`NB&ZO__3(L,)$2)^4F)V$F)Q4B)Q[K_____O@$````QP.CEZ?__BU0D"+\!
M````3(GNZ'3H__],B>^#^/]T$(M$)"@E`/```#T`0```=#SH%^K__TR)[^A?
MY___2(GOZ`?G__^%P`^%/____P\?@`````!(B>_H4.?__TB)W^AXZ?__Z<+^
M__\/'P#HB_[__^O"Z/3G__\/'T``4TB)_DB)^[\!````@>R@````9(L$)1@`
M``")A"2<````,<")XNAVZ?__A<!U,HM4)!B!X@#P``"!^@!```!T"('Z`*``
M`'4:O@(```!(B=_HZ^;__X7`#Y3`#[;`ZP.0,<"+C"2<````9#,,)1@```!U
M"('$H````%O#Z'#G__]!5KK_#P``055)B?5!5$F)_(T]YB4``%53@>P0$```
M9(L$)1@```")A"0,$```,<")YDB)]>AVZ?__A<!^<HU8_XL5284``&>`/!P`
M9T2+,G56A=MT9(G:OB\```!(B>_H*^C__X7`=%%$B??H/^C__XG92(GJ3(GF
M2(G'Z+_G__^+A"0,$```9#,$)1@```!U0('$$!```%M=05Q!74%>PP\?@```
M``")P^NJ#Q]``(L%VH0``&=$BS!$B??H[N?__TR)ZDR)YDB)Q^B0YO__ZZ_H
MF>;__V8/'X0``````(/L"(L%IX0``&>+..B_Y___BQ7!A```@\0(C0WH)@``
MC34&)0``2(G'Z8+H__]FD%.+'7F$``!GBSOHD>?__TB)Q^BY____9XL[Z('G
M__^-#6$F``!%,<E;Q\(`34``28G(C37@)```2(G'Z8#F__]!5%53@>P@(```
M9(L$)1@```")A"0<(```,<")XXVL)!`0``#HA^;__TB)WXT-NR0``$2-#7\D
M``!!B<"Z`1```+X!````,<#H4^?__TB)W[H`$```2(GNZ`/H__\QVX7`>"6-
M>`%!B<3HLN?__XG#A<!T%$2)XDB)[DB)Q^@>YO__9T+&!",`BXPD'"```&0S
M#"48````B=AU"X'$("```%M=05S#Z'7E__\/'T0``.E+____9F8N#Q^$````
M``!!5T%6055!5$F)_(T]*"0``%5(B?53@>S($```9(L$)1@```")A"2\$```
M,<"-="0<Z"KX__^^+P```$R)YXG#Z/OE__^%P'0_3(GFC3WP(P``,<#H5_G_
M_XN4)+P0``!D,Q0E&````$2)X`^%?@$``('$R!```%M=05Q!74%>05_#9@\?
M1```3(GG1(TMO2,``.@9YO__3(GN2(GO08G&Z.OD__]!B<>%P'2=1(G]C80D
ML````&>`?0``B40D#`^$R`````\?`$&)[X7;=!*)WTR)_N@GY?__A<`/A(T`
M``!,B?_HQ^7__V>`?`7_+W48#Q^``````(/H`6>`?`7_+V?&1`4``'3O0HU$
M,`$]_P\```^/,/___T2+?"0,@^P(08GH,<!!5(T-"20``+H`$```1(T-%R,`
M`+X!````3(G_Z)GE__^-5"0P3(G^OP$```#H*.3__UI9A<!U$(M$)#@E`/``
M`#T`@```=%),B>XQ_^@8Y/__B<6%P`^$Q_[__V>`?0``#X4[____A=MT'[D"
M````B=Z-/4<B``!G\Z8/E\`<`(3`=,1F#Q]$``"-+2\B``"X`0```.E)____
MO@$```!,B?_HX^+__X7`=9U,B?Z-/6@B``#HT??__TR)_^B)Y/__08G$Z6K^
M___H;./__V9F+@\?A```````D&</M@^$R709B?IF#Q]$``"#P@&`^2]G#[8*
M#T3ZA,EU[XGXPV9F+@\?A```````D$B%_P^$IP```&>`/P`/A)T```!54TB)
M^X/L".A@Y/__C508_SG:=P_K(V8/'T0``(/J`3G:=!IG@#HO=//K!Y!G@#HO
M=#"#Z@$YVG?S.=IU)6>`.B]T:8/$"(T]P2$``%M=Z=GC__]F#Q^$``````!G
M@#HO=0>#Z@$YVG?S*=HQP(U*`H'Y`!```'<;C3T^@P``@\(!N0`0``!(B=Y(
MB?WH.^/__XGH@\0(6UW##Q\`C3W_(```Z87C__\/'T0``(/$"(T]["```%M=
MZ7#C__]!5HT]2R$``$2--8LA``!!542-+7@A``!!5$2-)1@A``!5C2U,(0``
M4X/L0/,/;P5\(@``\P]O#80B``!DBP0E&````(E$)#PQP`^W!7\B```/*40D
M$&:)1"0P,<`/*4PD(.C)]?__,<"-/>T@``#HO/7__S'`C3WH(```Z*_U__\Q
MP(T]Y"```.BB]?__,<!(B>_HF/7__S'`C3WD(```Z(OU__\QP$R)Y^B!]?__
M,<!,B>_H=_7__S'`3(GWZ&WU__\QP(T]V2```.A@]?__,<"-/6H@``#H4_7_
M_XUT)`PQP(T]Q2```$B)\^AO]/__A<!T#4B)QDR)]S'`Z*[U__\QP(G>C3VS
M(```Z$_T__^%P'002(G&C3VS(```,<#HB_7__S'`2(G>C3VL(```Z"OT__^%
MP'0W2(G&3(GG,<#H:O7__S'`C36Z(```2(GOZ%KU__^+1"0\9#,$)1@```!U
M8(/$0%M=05Q!74%>PS'`2(G>C3UQ(```Z.#S__^%P'042(G&3(GO,<#H'_7_
M_^NS#Q]$``"-="0AN0H```"-/58@``!G\Z:-5"00#Y?`'`"$P'6/C7(;3(GO
MZ.[T___K@NB7X/__#Q^``````(/L&&2+!"48````B40D##'`BP7Q@```@_C_
M=!2+?"0,9#,\)1@```!U.X/$&,-FD(UT)`B-/88?```QP.A/\___2(G",<"%
MTG039P^V$H#Z,`^5P3'`A-(/E<`AR(D%I8```.NWZ";@__]F#Q]$``"#[`CH
MF-___XG'Z&'@__^%P'0-9XL`@\0(PV8/'T0``#'`@\0(PV8N#Q^$``````!!
M54%428G\58TM""```%-(B>^#[!ADBP0E&````(E$)`PQP(UT)`CHQ/+__X7`
M=`9G@#@`=2I,B>9(B>\QP.C]\___BT0D#&0S!"48````=7V#Q!A;74%<05W#
M#Q]$``!,B>9(B<=(B</H<M[__X7`==%,B>?HQN#__TB)WT&)Q>B[X/__08U\
M!0+H8>'__X/L"+K_____38G@4TB)QTF)Q42-#3<>``"-#1D?``"^`0```#'`
MZ+;@__],B>Y(B>\QP.AY\___6%KI=?___^@=W___9F8N#Q^$``````!FD$%7
M059!54%455.![&B!``!(B7PD$(UT)#1(B?5DBP0E&````(F$)%R!```QP(T%
MDQX``,=$)$``````B40D.(T%4!T``(E$)#R-!3(>``")1"10C04A'@``B40D
M5(T%:!X``(E$)%B-!2H>``")1"1<C05<'@``B40D8(T%.1X``(E$)$2-!4P>
M``")1"1(C054'0``2(E$)"!(B<<QP,=$)&0`````QT0D3`````#H7/'__X7`
M=`IG@#@`#X7&!```,<#H)_[__T&)QH7`#X0\!```1(GWZ(3?__^-?``!Z"O@
M__]G08`^`(G#=#M!B=]$C27H'0``0;W_____9I!G10^V!D2)_S'`3(GA1(GJ
MO@$```!!@\8!08/'`NANW___9T&`/@!UUT2-="10C3U-'0``08GLZQ</'X``
M````08/&!&=!BSZ%_P^$F`$``$R)YC'`Z+;P__])B<6%P'3?9X`X`'392(G'
MZ+'U__^%P'3-3(GOZ*7>__]!B<2%P`^$8@$``&8N#Q^$``````!$B>%GBQ&#
MP02-@O_^_O[WTB'0)8"`@(!TZ8G"P>H0J8"````/1,*-40(/1,J)P@#"B=J#
MV0-$*>%GBS*#P@2-AO_^_O[WUB'P)8"`@(!TZ8G&P>X0J8"````/1,:-<@(/
M1-:)QD``QH/:`RG:1(VT$00$``!$B??H`]___T2-#>T;``!%B>"-#<@<``!(
MB<=!B<5,B0PDNO____](B40D"(T%MQP``+X!````4TB)^U`QP.A(WO__OL`!
M``!(B=_HJ]W__T%805F#^/]U$^A]W/__9T2+"$&#^1$/A>0"``!(BW0D"(U4
M)'"_`0```$F)U.@YWO__B<.%P`^$KP```(M$)!!,BT0D"+X!````13'DC14P
M'0``9XL(BP6_>@``9XLX,<#H%=[__XN,)%R!``!D,PPE&````$R)X`^%L@<`
M`('$:($``%M=05Q!74%>05_##Q]``$4Q[0\?1```9T*+?*PXA?]T-F>`/P!T
M,$&)_$&#Q0%,B>?H$?3__X7`=-U,B>?H!=W__T&)Q(7`#X5J_O__9T*+?*PX
MA?]URD4QY.E8_O__#Q^$``````"+A"2(````)0#P```]`$````^%.O___XN$
M)(P```!!B<?H*MO__T$YQP^%(O___XN$)(@````E_P$``#W``0``#X4+____
M1(GWZ(+=__^)[HT]71L``$B)1"08B40D*#'`Z&KN__^%P`^$$@(``$B)Q^AJ
MW/__BTPD$$B)QF>+.>CK]?__B<6%P`^$\0$``(GOZ(K<__^#^`-V-8UT!?RY
M!0```(T]#AL``&?SI@^7PH#:`(32=1F#^`0/A"T%``!G@'P%^R\/A"$%```/
M'T``,<#H:?K__X7`=12)[S'VZ'S:__]!B<:%P`^%G0$``(TU@QH``(T]!1H`
M`#'`Z![O__]$C37M&@``1(T]SQH``.A+V___05:Z_____XT-KQH``%!,BTPD
M$+X!````,<!,BT0D&$B+?"0HZ!+<__]86D2+9"0HZT)F#Q^$``````#H2]K_
M_V>#.!%U0N@`V___@\,!@^P(1(GY059%B>B)ZKX!````4TR)YU!,BTPD(#'`
MZ,K;__^#Q""^P`$``$R)Y^@JV___B<6#^/]TLTB+?"0(Z%G9__](BUPD&$B+
M?"0@,<!(B=[H9>[__TB)W^@=^O__Z;/]__\/'X0``````(T]I!D``$4QY(GK
MZPD/'P!G0HM\I$2%_W1^2(G>,<!!@\0!Z-CL__^)QX7`=.)G@#\`=-SHU]K_
M_T&)QH7`=-#I?_O__XM$)!!,BT0D"+X!````13'DC14L&@``9XL(BP7[=P``
M9XLX,<#H4=O__^DW_?__#Q]``$B)QTB)!"3HC/G__TB+!"1(B<?H@-K__TF)
MQ.D3_?__OPT```!$C34+&0``Z%?;__^)P^DN^___BT0D$&>+*.D#_O__N@(`
M``!(Q\;N____B<?H0=O__XV<)%`!``"Z!@```$2)]TB)WHE<)!#HIMK__X"\
M)%`!````=0Z`O"11`0``0P^$[`,``#'2,?9$B??H`MO__TBX`2-%9XFKS>_'
MA"2(`````````$B)1"1P2+C^W+J8=E0R$$B)1"1XN/#ATL-(B80D@````,>$
M),P`````````D$2+;"00N@"```!$B?=,B>[H*]K__XG#A<`/CCL!```QR8T$
MW0`````#A"2$````BY0DB`````^2P8F$)(0```")V(/Y`8/:_\'H'0'0BY0D
MS````(F$)(@```"%T@^$[0```+A`````08U\%!Q,B>XIT#G##T[#B<)!B<?H
MK]C__XN$),P```!$`?B)A"3,````@_A`#X5E____1(GG1"G[1`-\)!#H9=W_
M_X/[/P^.7P(``(/K0$6)Y8G8P>@&C6@!B40D+,'E!D0!_0\?0`!G\T$/;P],
MB>]!@\=`9_-!#V]7T&?S00]O7^!G\T$/;V?P#Q&,)(P````/$90DG`````\1
MG"2L````#Q&D)+P```#H^=S__T0Y_76T1(M\)"Q!P><&1"G[B>Y!C7PD'+E$
M````B=KH-=C__XF<),P```#IN?[__V8/'X0``````$2+?"00Z5'___]$B??H
MKM;__XN$)(0```!(BYPDA````,'H`T@/RX/@/V?&A`2,````@(U0`8/Z.`^.
MC`$``+A`````08U,%!PIT(G"=`XQP&?&!`$`@\`!.=!R]$2)Y^A;W/__9@_O
MP`\1A"2,````9TG'1"1,`````&=!#Q%$)"QG00\11"0\1(GG1(VL)"`!``!(
MB9PDQ````$2-O"0!`0``Z!?<__]$BT0D<$6)[D&-72A$C25T%@``O?____]$
MB<!!P>@8#\B)A"0``0``BT0D=`_(B80D!`$``(M$)'@/R(F$)`@!``"+1"1\
M#\B)A"0,`0``BX0D@`````_(B80D$`$``.L/9@\?1```9T4/M@=!@\<!1(GW
M10^VP$R)X8GJO@$````QP$&#Q@+HJ]?__T0Y\W76QH0D2`$```"-!3X6``!0
M055,BTPD$$R+1"08O@$````QP$B+?"0HC0WK%0``NO_____H;]?__UE>1(MD
M)"CIL/O__XM$)!!G1(MP!$6%]@^$T?K__T2)]^@9U___@_@##X;`^O__08UT
M!ORY!0```(T]G14``&?SI@^7P!P`A,!!#T3NZ9WZ__]$B?WI#?[__[@X````
M,?8IT$&-5!0<@_@(<S*H!`^%V@```(7`#X2;_O__9\8"`*@"#X2/_O__,?]G
M9HE\`O[I@O[__V8/'X0``````(U*"&=(QP(`````9TC'1`+X`````(/A^"G*
M`="#X/B#^`@/@E'^__^#X/@QTF=(B301@\((.<)R].D[_O__@+PD4@$``$$/
MA0;\__^`O"13`0``0P^%^/O__X"\)%0!``!(#X7J^___@+PD50$``$4/A=S[
M__^Z`@```$C'QL;___]$B??HUM;__[HI````2(G>1(GWZ$;6__^-!=84``!0
M4^F4_O__9@\?A```````9\<"`````&?'1`+\`````.FT_?__Z(;4__]F#Q]$
M``!!5T%6055!5%53@^P8BRV-<@``9(L$)1@```")1"0,,<!GBWT`Z);5__]G
MBWT`B</HB]7__V</ME-DC70D"(T]4!,``$F)]6>(4&4QP.@NY___A<!T"F>`
M.#$/A-`"```QP.BY\?__9XM]`.A0U?__N0L```"Z`0```(TU(!0``$B)Q^BX
MT___A<`/A+@```!GBT`,@SV-A````6=$BW4`9T2+8!@/CJ(````QV^LXD&=!
MBT<,B<:+!6>$``!$C7L!9T*+/+CH5=3__XL55X0``(7`#X7B`0``@\,".=I$
MB?L/CM0!``!$B??HT=3__S')B=I,B>9(B<?H@M3__X7`#X2J`0``9T2+.&=$
MBW4`9T&+1P@E``0@`#T`!```=)!$B??HF-3__T2)_KD"````,=)(B<?HEM7_
M_V=$BW4`Z7'___\/'T``9T2+=0!$B??H:]3__[D#````N@$```"--4`3``!(
MB<?HT]+__T&)Q(7`=#1GBT`,9XM]`&>+&.@\U/__C14=$P``B=Y(B<?HW-+_
M_V=!BT0D#&>+&&?V0PI`#X7!`0``9XM]`.@/U/__N0,```"Z`0```(TUZQ(`
M`$B)Q^AWTO__B<.%P'0X1(GNC3V*$0``,<#HH>7__TF)Q(7`#X16`0``9XM#
M#&>+?0!GBQCHQM/__TR)XHG>2(G'Z&G2__]GBWT`Z+#3__^Z`0```(TUDQ(`
M`$B)Q^A=T?__9XM]`$B)P^B1T___C16.$@``2(G>2(G'Z##2__]GBWT`Z'?3
M__]$B>Z-/0<1``!GQD!E`#'`Z"+E__^)PHD%QH(``(7`#X22````B=.^P`$`
M`$B)W^CSTO__C5`!@_H!=@F#^!$/A?@```"+1"0,9#,$)1@````/A>$```"#
MQ!A;74%<05U!7D%?PV:0BQ5R@@``9T2+=0"-0O\YV`^%A_[__X/Z`0^.?O[_
M_[L!````#Q]``$2)]X/#`>C=TO__3(GF2(G'Z$+1__\Y'32"``!G1(MU`'_=
MZ4W^__^+/1Z"``#H9?+__XG"B049@@``A<`/A5/___^-/7\2``#H*M/__V8N
M#Q^$``````!G@'@!``^$+/W__^D@_?__BP7>@0``9XM]`&=$BR!GBT,,9XL8
MZ&;2__]$B>:)W^BLZ?__Z9[^__]GBWT`Z$[2__^)WDB)Q^ADTO__Z2?^___H
M^M#__XL5F($``(G!C3TT$@``,<!GBS)(B=KHK]+__V9F+@\?A```````#Q]`
M`%532(G[@^P(Z)/M__](B<?H6^W__TB)Q3'`Z"'P__^%P'0D2(7;=!]G@#L`
M=!FY!````(T]=1```(GN9_.F#Y?`'`"$P'0)@\0(6UW##Q\`@\0(2(G?6UWI
M`^?__P\?`/,/'OI!5TF)UT%628GV055!B?U!5$2-)51M``!5C2U1;0``4T0I
MY8/L".C!SO__P?T"=",QVV8N#Q^$``````!G08L$G(/#`4R)^DR)]D2)[__0
M.=UUZ8/$"%M=05Q!74%>05_#9F8N#Q^$``````#S#Q[ZPV8N#Q^$``````"0
M\P\>^HL-6G```.F!T?__`/,/'OI(@^P(2(/$",,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#0U`"UE`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@```````1L#.^@````<````V(#__RP!``"8A/__1`8``*B&__\$`0``V(;_
M_Q@!``"8A___4`$``#B5__^0`0``");__]P!``"(EO__"`(``,B8__]4`@``
M2)K__Z`"``#(FO__Q`(``*B;__\(`P``V)O__R`#```8G/__/`,``,B<__]P
M`P``V)S__X0#``#8GO__Y`,```B?___X`P``V)___T0$``"HH?__B`0``!BB
M__^D!```2*+__\0$```HH___#`4``+BM___$!0``:+'__Q`&``#(L?__<`8`
M`#BR__^X!@``2++__\P&```4``````````%Z4@`!>!`!&PP'")`!```0````
M'````)R%__\P`````$0'$!`````P````N(7__P4`````````(````$0```"D
M?___P`,````.$$8.&$H/"W<(@``_&CLJ,R0B/````&@```!`AO__FPT```!"
M#A"-`D4.&(P#00X@A@1!#BB#!48.@`,#@`T*#BA!#B!!#AA"#A!"#@A!"P``
M`$@```"H````H)/__\4`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$.
M.(,'0PY``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A*"P`H````]````"24__]Y
M`````$$.$(8"1`X8@P-##C`":0H.&$$.$$$."$$+`$@````@`0``>)3__S,"
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1@Y@`QT!"@XX00XP
M00XH0@X@0@X80@X00@X(1@M(````;`$``&R6__]\`0```$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T8.\`%Z"@XX00XP00XH0@X@0@X80@X00@X(
M1`L`(````+@!``"@E___@`````!!#A"#`E$.L`$"9PH.$$$."$$+0````-P!
M``#\E___UP````!"#A".`D<.&(T#10X@C`1*#BB&!4$.,(,&1@[`(`)Y"@XP
M00XH00X@0@X80@X00@X(2`L4````(`(``)B8__\N`````$,.$%<."``8````
M.`(``+"8__]``````$$.$(,":`X(````,````%0"``#4F/__JP````!"#A",
M`D$.&(8#00X@@P1&#L!``I<*#B!!#AA!#A!"#@A!"Q````"(`@``4)G__P4`
M````````7````)P"``!,F?__]`$```!"#A"/`D(.&(X#0@X@C01"#BB,!4H.
M,(8&1`XX@P=&#H`B`EL*#CA!#C!!#BA"#B!"#AA"#A!"#@A'"P*9#H@B1PZ0
M(G$.B")!#H`B````$````/P"``#LFO__)`````````!(````$`,```B;___0
M`````%0.$(8"00X8@P-&#B!_"@X81\,.$$'&#@A."WH.&$$.$$$."$3#QE`.
M((,#A@)##AA'PPX00<8."```0````%P#``",F___R0$```!"#A".`D\.&(T#
M20X@C`1(#BB&!4<.,(,&0PYP`SL!"@XP00XH00X@0@X80@X00@X(00L8````
MH`,``!B=__]J`````$,.(&H*#@A#"P``'````+P#``!LG?__)@````!##A!6
M"@X(1PM%#@@```!$````W`,``'R=___3`````$(.$(T"0@X8C`-$#B"&!$<.
M*(,%1@Y`?PH.*$$.($$.&$(.$$(."$8+<@Y(20Y0;0Y(00Y```"T````)`0`
M`!2>__^*"@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T8.H(,"
M`RT"#JB#`D0.L(,"5@ZH@P)"#J"#`@*`"@XX00XP00XH0@X@0@X80@X00@X(
M10L#;P$.J(,"3`ZP@P)<#JB#`D$.H(,"9@ZH@P)%#K"#`DL.N(,"1`[`@P)/
M#J"#`@,P!`ZH@P)"#K"#`F<.J(,"00Z@@P(#/@$*#JB#`D$.L(,"3@L`2```
M`-P$``#LI___H0,```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=#
M#E`#E@(*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"S`````H!0``4*O__UT`````
M00X0A@)!#AB#`T8.(`)""@X800X000X(1`M##AA$#A!!#@@H````7`4``$Q^
M__\(`@```$$.$(8"00X8@P-##D`#:0$*#AA!#A!!#@A!"T0```"(!0``4*O_
M_V4`````1@X0CP)%#AB.`T4.((T$10XHC`5(#C"&!D<..(,'1@Y`<`XX00XP
M00XH0@X@0@X80@X00@X(`!````#0!0``>*O__P4`````````$````.0%``!T
MJ___#P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#0)D``H"9```$````!
M`````0```,T!```!````V`$```$```#B`0```0```#$"```!````;@,```\`
M``"Q!```#``````@0``-````H%%``!D```"`OD``&P````0````:````A+Y`
M`!P````$````]?[_;Q0"0``%````"`E```8```#H`D``"@```/0$```+````
M$````!4``````````P````#`0``"````Q`(``!0````'````%P```)`/0``'
M``````]```@```"0````"0````P```#^__]OP`Y``/___V\"````\/__;_P-
M0```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"(OD`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0`````````````````#_____$&-``$=#0SH@*%!,1"U,:6YU>"D@
M."XR+C`@,C`Q.#`W,C8@*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````
M```````````````````````````````````````````````````````+````
M`0````(```"T`4``M`$``!H```````````````$`````````$P````<````"
M````T`%``-`!```@```````````````$`````````"$````'`````@```/`!
M0`#P`0``)```````````````!``````````T````]O__;P(````4`D``%`(`
M`-0````%``````````0````$````/@````L````"````Z`)``.@"```@!@``
M!@````$````$````$````$8````#`````@````@)0``("0``]`0`````````
M`````0````````!.````____;P(```#\#4``_`T``,0````%``````````(`
M```"````6P```/[__V\"````P`Y``,`.``!`````!@````(````$````````
M`&H````$`````@`````/0```#P``D`````4`````````!`````P```!T````
M!````$(```"0#T``D`\``,0"```%````%@````0````,````?@````$````&
M`````"!````@```;```````````````$`````````'D````!````!@```"`@
M0``@(```P`,`````````````$````!````"$`````0````8```#@(T``X",`
M`+\M`````````````!``````````B@````$````&````H%%``*!1```-````
M```````````$`````````)`````!`````@````!@0```8```2#\`````````
M````"`````````"8`````0````(```!(GT``2)\``.P```````````````0`
M````````I@````$````"````-*!``#2@``#X!0`````````````$````````
M`+`````.`````P```("^0`"`K@``!```````````````!`````0```"\````
M#P````,```"$OD``A*X```0```````````````0````$````R`````8````#
M````B+Y``(BN```8`0``!@`````````$````"````-$````!`````P```*"_
M0`"@KP``8```````````````"`````@```#6`````0````,`````P$```+``
M`/`!``````````````@````(````WP````$````#````\,%``/"Q```0````
M```````````$`````````.4````(`````P````#"0```L@``-!``````````
M````(`````````#J`````0```#```````````+(``"H```````````````$`
M```!`````0````,``````````````"JR``#S```````````````!````````
!````
